import 'package:arch/src/dialog.dart';
import 'package:arch/src/listenable_model.dart';
import 'package:arch/src/navigation.dart';
import 'package:meta/meta.dart';

/// Base class for view models.
abstract class ViewModelBase extends ListenableModel {
  ViewModelBase({this.navigationService, this.dialogService});

  @protected
  final NavigationService navigationService;

  @protected
  final DialogService dialogService;

  /// Called to initialize this object.
  ///
  /// Override this method to implement you custom initialization logic.
  Future<void> init([Map<String, Object> parameters]) => Future<void>.value();
}

/// Base class for dialog models.
abstract class DialogModelBase extends ListenableModel {
  DialogModelBase(this._dialogService);

  final DialogService _dialogService;

  /// Called to initialize this object.
  ///
  /// Override this method to implement you custom initialization logic.
  Future<void> init([Map<String, Object> parameters]) => Future<void>.value();

  /// Closes the dialog this model is attached to.
  ///
  /// Returns an [optional] result.
  @nonVirtual
  void pop([Map<String, Object> result]) => _dialogService.pop(result);
}
